knmy
===============================
[![Build Status](https://travis-ci.org/barthoekstra/knmy.svg?branch=master)](https://travis-ci.org/barthoekstra/knmy)
[![Coverage Status](https://coveralls.io/repos/github/barthoekstra/knmy/badge.svg?branch=master)](https://coveralls.io/github/barthoekstra/knmy?branch=master)
[![Documentation Status](https://readthedocs.org/projects/knmy/badge/?version=latest)](http://knmy.readthedocs.io/en/latest/?badge=latest)


version number: 1.0.0
author: Bart Hoekstra

Overview
--------

Python package for downloading and processing weather data from the automated weather stations of the Dutch Meteorological Institute (KNMI). Documentation of the used API can be [found here](https://www.knmi.nl/kennis-en-datacentrum/achtergrond/data-ophalen-vanuit-een-script) (only in Dutch).

Documentation
-------------

Documentation can be found on [Read the Docs](http://knmy.readthedocs.io/).
